@@ -563,12 +563,10 @@ bamf_application_ensure_flags (BamfApplication *self)
     }
 
   close_when_empty = bamf_application_get_close_when_empty (self);
-  bamf_view_set_urgent       (BAMF_VIEW (self), urgent);
-  if (close_when_empty == TRUE || running == TRUE)
-    bamf_view_set_user_visible (BAMF_VIEW (self), visible);
-  if ((running == TRUE) || close_when_empty)
-    bamf_view_set_running      (BAMF_VIEW (self), running);
-  bamf_view_set_active       (BAMF_VIEW (self), active);
+  bamf_view_set_urgent (BAMF_VIEW (self), urgent);
+  bamf_view_set_user_visible (BAMF_VIEW (self), (visible || !close_when_empty));
+  bamf_view_set_running (BAMF_VIEW (self), (running || !close_when_empty));
+  bamf_view_set_active (BAMF_VIEW (self), active);
 }
 
 static void
@@ -720,7 +718,7 @@ bamf_application_child_removed (BamfView *view, BamfView *child)
 
   bamf_application_ensure_flags (self);
 
-  if ((bamf_view_get_children (view) == NULL)  && (bamf_application_get_close_when_empty (self)))
+  if (!bamf_view_get_children (view) && bamf_application_get_close_when_empty (self))
     {
       bamf_view_close (view);
     }
